==> hazelcast-jet-3.2.2-sources.jar: com/hazelcast/map/impl/operation/MapPartitionDestroyOperation.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.operation;


import com.hazelcast.map.impl.MapContainer;
import com.hazelcast.map.impl.PartitionContainer;
import com.hazelcast.spi.AbstractLocalOperation;
import com.hazelcast.spi.PartitionAwareOperation;
import com.hazelcast.spi.impl.AllowedDuringPassiveState;

/**
 * Operation to destroy the map data on the partition thread
 */
public class MapPartitionDestroyOperation extends AbstractLocalOperation
        implements PartitionAwareOperation, AllowedDuringPassiveState {
    private final PartitionContainer partitionContainer;
    private final MapContainer mapContainer;

    public MapPartitionDestroyOperation(PartitionContainer container, MapContainer mapContainer) {
        this.partitionContainer = container;
        this.mapContainer = mapContainer;
        setPartitionId(partitionContainer.getPartitionId());
    }

    @Override
    public void run() {
        partitionContainer.destroyMap(mapContainer);
    }

    @Override
    public boolean validatesTarget() {
        return false;
    }
}

==> hazelcast-jet-4.5.2-sources.jar: com/hazelcast/map/impl/operation/MapPartitionDestroyOperation.java <==
/*
 * Copyright (c) 2008-2021, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.operation;


import com.hazelcast.map.impl.MapContainer;
import com.hazelcast.map.impl.PartitionContainer;
import com.hazelcast.spi.impl.operationservice.AbstractLocalOperation;
import com.hazelcast.spi.impl.operationservice.PartitionAwareOperation;
import com.hazelcast.spi.impl.AllowedDuringPassiveState;

/**
 * Operation to destroy the map data on the partition thread
 */
public class MapPartitionDestroyOperation extends AbstractLocalOperation
        implements PartitionAwareOperation, AllowedDuringPassiveState {
    private final PartitionContainer partitionContainer;
    private final MapContainer mapContainer;

    public MapPartitionDestroyOperation(PartitionContainer container, MapContainer mapContainer) {
        this.partitionContainer = container;
        this.mapContainer = mapContainer;
        setPartitionId(partitionContainer.getPartitionId());
    }

    @Override
    public void run() {
        partitionContainer.destroyMap(mapContainer);
    }

    @Override
    public boolean validatesTarget() {
        return false;
    }
}
